# Section

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**automation** | [**ReportAutomation**](ReportAutomation.md) |  | [optional] 
**data** | **object** |  | [optional] 
**description** | **str** |  | [optional] 
**display_type** | **str** |  | [optional] 
**empty_notification** | **str** |  | [optional] 
**from_date** | **str** |  | [optional] 
**layout** | **object** |  | [optional] 
**query** | [**ReportQuery**](ReportQuery.md) |  | [optional] 
**title** | **str** |  | [optional] 
**title_style** | **dict(str, object)** |  | [optional] 
**to_date** | **str** |  | [optional] 
**type** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


